@@ -1,6 +1,6 @@
 package Apache::Session::Browseable;
 
-our $VERSION = '1.2.4';
+our $VERSION = '1.2.5';
 
 print STDERR "Use a sub module of Apache::Session::Browseable such as Apache::Session::Browseable::File";
 
@@ -92,8 +92,8 @@ Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
 =encoding utf8
 
-Copyright (C) 2009-2013 by Xavier Guimard
-              2013 by Clément Oudot
+Copyright (C) 2009-2017 by Xavier Guimard
+              2013-2017 by Clément Oudot
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.1 or,
