@@ -9,7 +9,7 @@ use Apache::Session::Generate::SHA256;
 use Apache::Session::Serialize::JSON;
 use Apache::Session::Browseable::DBI;
 
-our $VERSION = '1.2';
+our $VERSION = '1.2.5';
 our @ISA     = qw(Apache::Session::Browseable::DBI Apache::Session);
 
 sub populate {
@@ -26,7 +26,6 @@ sub populate {
 }
 
 1;
-
 __END__
 
 =head1 NAME
@@ -36,6 +35,26 @@ Apache::Session::MySQL
 
 =head1 SYNOPSIS
 
+Create table with columns for indexed fields. Example for Lemonldap::NG:
+
+  CREATE TABLE sessions (
+      id varchar(64) not null primary key,
+      a_session text,
+      _whatToTrace text,
+      _session_kind text,
+      _utime bigint,
+      ipAddr text
+  );
+
+Add indexes:
+
+  CREATE INDEX uid1 ON sessions (_whatToTrace);
+  CREATE INDEX s1   ON sessions (_session_kind);
+  CREATE INDEX u1   ON sessions (_utime);
+  CREATE INDEX ip1  ON sessions (ipAddr);
+
+Use it with Perl:
+
   use Apache::Session::Browseable::MySQL;
 
   my $args = {
@@ -104,8 +123,8 @@ Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
 =encoding utf8
 
-Copyright (C) 2009-2013 by Xavier Guimard
-              2013 by Clément Oudot
+Copyright (C) 2009-2017 by Xavier Guimard
+              2013-2017 by Clément Oudot
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.10.1 or,
