@@ -2,7 +2,7 @@
 package Apache::Session::Serialize::JSON;
 
 use strict;
-use JSON;
+use JSON qw(to_json from_json);
 
 our $VERSION = '1.2.2';
 
@@ -83,9 +83,9 @@ L<http://jira.ow2.org>
 
 =over
 
-=item Copyright (C) 2015-2016 by Clément Oudot, E<lt>clem.oudot@gmail.comE<gt>
+=item Copyright (C) 2015-2017 by Clément Oudot, E<lt>clem.oudot@gmail.comE<gt>
 
-=item Copyright (C) 2015-2016 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+=item Copyright (C) 2015-2017 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
 
 =back
 
